==> church_of_jesus_christ_api-0.2.3.tar.gz: church_of_jesus_christ_api-0.2.3/doc/source/JSON_schemas/get_suborganization-schema.md <==
{
  addableSubOrgTypes: NoneType,
  adultClass: bool,
  callings: list,
  canHaveMembers: bool,
  canShowWithNoCallings: bool,
  children: [
    {
      addableSubOrgTypes: NoneType,
      adultClass: bool,
      callings: [
        {
          activeDate: str,
          allowApprove: bool,
          allowMultiple: bool,
          allowNew: bool,
          allowVacant: bool,
          approvalRequest: bool,
          autoReleasedPositionTypeIds: NoneType,
          canHaveResponsibilities: bool,
          contactEmail: str,
          contactInfoEditable: bool,
          contactMailingAddr: NoneType,
          contactMobilePhone: NoneType,
          contactWorkPhone: NoneType,
          custom: bool,
          customNameChanged: bool,
          dualAuthPass: NoneType,
          dualAuthUser: NoneType,
          editable: bool,
          errors: {},
          expectedEndDate: NoneType,
          hasContactInfo: bool,
          hidden: bool,
          memberEmail: str,
          memberId: int,
          memberName: str,
          memberNameOrder: int,
          memberPhone: str,
          memberUnitName: str,
          memberUnitNumber: int,
          missionName: NoneType,
          missionUnitNumber: NoneType,
          missionary: bool,
          missionaryHomeUnitName: NoneType,
          mrn: NoneType,
          nameVerificationForMrn: NoneType,
          newSubOrgId: NoneType,
          ordainDate: NoneType,
          ordainedByPersonId: NoneType,
          ordainedByPersonMrn: NoneType,
          ordainedByPersonName: NoneType,
          organization: str,
          otherAllowedSubOrgs: [
            {
              children: list,
              classGroup: NoneType,
              defaultOrgTypeIds: [
                int
              ],
              firstTypeId: int,
              gender: NoneType,
              isClass: bool,
              isCombined: bool,
              isRealClass: bool,
              isSplit: bool,
              name: str,
              orgTypeIds: [
                int
              ],
              parentName: str,
              subOrgId: int,
              unitNumber: int,
              userCanEditCallings: bool
            }
          ],
          parentOrganization: NoneType,
          pendingCalling: bool,
          pendingDelete: bool,
          pendingDualAuth: bool,
          position: str,
          positionDisplayOrder: int,
          positionId: int,
          positionTypeEnum: str,
          positionTypeId: int,
          previouslyOrdained: bool,
          releaseDate: NoneType,
          releasePositionIds: NoneType,
          requiresBishopOrdination: bool,
          requiresDualAuthorization: bool,
          requiresSetApartDateAndPerson: bool,
          responsibilities: NoneType,
          sequence: int,
          setApart: bool,
          setApartByPersonId: NoneType,
          setApartByPersonMrn: NoneType,
          setApartByPersonName: NoneType,
          setApartDate: str,
          showUnitCard: bool,
          subOrgId: int,
          subOrgTypeId: int,
          unitName: NoneType,
          unitNumber: int,
          unpublished: bool,
          userCanEdit: bool,
          userCanEditContactInfoOnly: bool,
          userCannotEditPreviousOrdination: bool,
          vacant: bool
        }
      ],
      canHaveMembers: bool,
      canShowWithNoCallings: bool,
      children: list,
      classGroup: NoneType,
      classes: NoneType,
      classesCollapsed: bool,
      customOrgName: NoneType,
      customPositionsAllowed: bool,
      defaultOrgName: str,
      displayOrder: int,
      enableHT: bool,
      enableVT: bool,
      filterOffices: list,
      firstOrgType: str,
      firstOrgTypeId: int,
      firstOrgTypeName: NoneType,
      gender: NoneType,
      hasAnyAllowMultiple: bool,
      hasCustomCallings: bool,
      highCouncilOrDistrictCouncil: bool,
      instance: int,
      isSplit: bool,
      leadershipSubOrgId: NoneType,
      members: list,
      mergeableSubOrgTypeIds: list,
      missionaries: bool,
      multipleAllowed: bool,
      name: str,
      nameEditable: bool,
      orgTypeIds: [
        int
      ],
      other: bool,
      parentName: str,
      parentSubOrgId: int,
      positionTypeIdsThatCanHaveResponsibilities: list,
      priesthood: bool,
      relatedSubOrgName: NoneType,
      required: bool,
      resetable: bool,
      room: NoneType,
      size: NoneType,
      splitOrCombinedClassNotice: NoneType,
      subOrgId: int,
      supportsAttendanceRoll: bool,
      totalInstances: int,
      unitNumber: int,
      unitType: int,
      userCanEditCallings: bool,
      userCanEditClassAssignments: bool,
      userCanSeeBasicInfo: bool
    }
  ],
  classGroup: str,
  classes: NoneType,
  classesCollapsed: bool,
  customOrgName: NoneType,
  customPositionsAllowed: bool,
  defaultOrgName: str,
  displayOrder: int,
  enableHT: bool,
  enableVT: bool,
  filterOffices: [
    {
      codes: [
        int
      ],
      name: str
    }
  ],
  firstOrgType: str,
  firstOrgTypeId: int,
  firstOrgTypeName: NoneType,
  gender: str,
  hasAnyAllowMultiple: bool,
  hasCustomCallings: bool,
  highCouncilOrDistrictCouncil: bool,
  instance: int,
  isSplit: bool,
  leadershipSubOrgId: NoneType,
  members: [
    {
      accountable: bool,
      actualAge: int,
      actualAgeInMonths: int,
      address: str,
      adultAgeOrMarried: bool,
      age: int,
      birthDate: str,
      birthDateFormatted: str,
      birthDateSort: str,
      birthDayFormatted: str,
      birthDaySort: str,
      defaultClass: bool,
      defaultClassTypeId: int,
      eligibleForHomeTeachingAssignment: bool,
      email: str,
      endowed: bool,
      formattedMrn: NoneType,
      gender: str,
      genderCode: int,
      genderLabelShort: str,
      householdEmail: NoneType,
      householdPhone: str,
      htvtAssignments: NoneType,
      htvtCompanions: NoneType,
      id: int,
      mrn: NoneType,
      name: str,
      nameOrder: int,
      nonMember: bool,
      notAccountable: bool,
      outOfUnitMember: bool,
      phone: str,
      priesthood: NoneType,
      priesthoodCode: int,
      priesthoodType: NoneType,
      sealedToSpouse: bool,
      setApart: bool,
      spokenName: str,
      sustainedDate: NoneType,
      unitName: str,
      unitNumber: int,
      visible: NoneType
    }
  ],
  mergeableSubOrgTypeIds: list,
  missionaries: bool,
  multipleAllowed: bool,
  name: str,
  nameEditable: bool,
  orgTypeIds: [
    int
  ],
  other: bool,
  parentName: str,
  parentSubOrgId: NoneType,
  positionTypeIdsThatCanHaveResponsibilities: list,
  priesthood: bool,
  relatedSubOrgName: NoneType,
  required: bool,
  resetable: bool,
  room: NoneType,
  size: NoneType,
  splitOrCombinedClassNotice: NoneType,
  subOrgId: int,
  supportsAttendanceRoll: bool,
  totalInstances: int,
  unitNumber: int,
  unitType: int,
  userCanEditCallings: bool,
  userCanEditClassAssignments: bool,
  userCanSeeBasicInfo: bool
}

==> church_of_jesus_christ_api-0.2.8.tar.gz: church_of_jesus_christ_api-0.2.8/doc/source/JSON_schemas/get_suborganization-schema.md <==
{
  addableSubOrgTypes: NoneType,
  adultClass: bool,
  callings: list,
  canHaveMembers: bool,
  canShowWithNoCallings: bool,
  children: [
    {
      addableSubOrgTypes: NoneType,
      adultClass: bool,
      callings: [
        {
          activeDate: str,
          allowApprove: bool,
          allowMultiple: bool,
          allowNew: bool,
          allowVacant: bool,
          approvalRequest: bool,
          autoReleasedPositionTypeIds: NoneType,
          canHaveResponsibilities: bool,
          contactEmail: str,
          contactInfoEditable: bool,
          contactMailingAddr: NoneType,
          contactMobilePhone: NoneType,
          contactWorkPhone: NoneType,
          custom: bool,
          customNameChanged: bool,
          dualAuthPass: NoneType,
          dualAuthUser: NoneType,
          editable: bool,
          errors: {},
          expectedEndDate: NoneType,
          hasContactInfo: bool,
          hidden: bool,
          memberEmail: str,
          memberId: int,
          memberName: str,
          memberNameOrder: int,
          memberPhone: str,
          memberUnitName: str,
          memberUnitNumber: int,
          missionName: NoneType,
          missionUnitNumber: NoneType,
          missionary: bool,
          missionaryHomeUnitName: NoneType,
          mrn: str,
          nameVerificationForMrn: NoneType,
          newSubOrgId: NoneType,
          ordainDate: NoneType,
          ordainedByPersonId: NoneType,
          ordainedByPersonMrn: NoneType,
          ordainedByPersonName: NoneType,
          organization: str,
          otherAllowedSubOrgs: [
            {
              children: list,
              classGroup: NoneType,
              defaultOrgTypeIds: [
                int
              ],
              firstTypeId: int,
              gender: NoneType,
              isClass: bool,
              isCombined: bool,
              isRealClass: bool,
              isSplit: bool,
              name: str,
              orgTypeIds: [
                int
              ],
              parentName: str,
              subOrgId: int,
              unitNumber: int,
              userCanEditCallings: bool
            }
          ],
          parentOrganization: NoneType,
          pendingCalling: bool,
          pendingDelete: bool,
          pendingDualAuth: bool,
          position: str,
          positionDisplayOrder: int,
          positionId: int,
          positionTypeEnum: str,
          positionTypeId: int,
          previouslyOrdained: bool,
          releaseDate: NoneType,
          releasePositionIds: NoneType,
          requiresBishopOrdination: bool,
          requiresDualAuthorization: bool,
          requiresSetApartDateAndPerson: bool,
          responsibilities: NoneType,
          sequence: int,
          setApart: bool,
          setApartByPersonId: NoneType,
          setApartByPersonMrn: NoneType,
          setApartByPersonName: NoneType,
          setApartDate: str,
          showUnitCard: bool,
          subOrgId: int,
          subOrgTypeId: int,
          unitName: NoneType,
          unitNumber: int,
          unpublished: bool,
          userCanEdit: bool,
          userCanEditContactInfoOnly: bool,
          userCannotEditPreviousOrdination: bool,
          vacant: bool
        }
      ],
      canHaveMembers: bool,
      canShowWithNoCallings: bool,
      children: list,
      classGroup: NoneType,
      classes: NoneType,
      classesCollapsed: bool,
      customOrgName: NoneType,
      customPositionsAllowed: bool,
      defaultOrgName: str,
      displayOrder: int,
      enableHT: bool,
      enableVT: bool,
      filterOffices: list,
      firstOrgType: str,
      firstOrgTypeId: int,
      firstOrgTypeName: NoneType,
      gender: NoneType,
      hasAnyAllowMultiple: bool,
      hasCustomCallings: bool,
      highCouncilOrDistrictCouncil: bool,
      instance: int,
      isSplit: bool,
      leadershipSubOrgId: NoneType,
      members: list,
      mergeableSubOrgTypeIds: list,
      missionaries: bool,
      multipleAllowed: bool,
      name: str,
      nameEditable: bool,
      orgTypeIds: [
        int
      ],
      other: bool,
      parentName: str,
      parentSubOrgId: int,
      positionTypeIdsThatCanHaveResponsibilities: list,
      priesthood: bool,
      relatedSubOrgName: NoneType,
      required: bool,
      resetable: bool,
      room: NoneType,
      size: NoneType,
      splitOrCombinedClassNotice: NoneType,
      subOrgId: int,
      supportsAttendanceRoll: bool,
      totalInstances: int,
      unitNumber: int,
      unitType: int,
      userCanEditCallings: bool,
      userCanEditClassAssignments: bool,
      userCanSeeBasicInfo: bool
    }
  ],
  classGroup: str,
  classes: NoneType,
  classesCollapsed: bool,
  customOrgName: NoneType,
  customPositionsAllowed: bool,
  defaultOrgName: str,
  displayOrder: int,
  enableHT: bool,
  enableVT: bool,
  filterOffices: [
    {
      codes: [
        int
      ],
      name: str
    }
  ],
  firstOrgType: str,
  firstOrgTypeId: int,
  firstOrgTypeName: NoneType,
  gender: str,
  hasAnyAllowMultiple: bool,
  hasCustomCallings: bool,
  highCouncilOrDistrictCouncil: bool,
  instance: int,
  isSplit: bool,
  leadershipSubOrgId: NoneType,
  members: [
    {
      accountable: bool,
      actualAge: int,
      actualAgeInMonths: int,
      address: str,
      adultAgeOrMarried: bool,
      age: int,
      birthDate: str,
      birthDateFormatted: str,
      birthDateSort: str,
      birthDayFormatted: str,
      birthDaySort: str,
      defaultClass: bool,
      defaultClassTypeId: int,
      eligibleForHomeTeachingAssignment: bool,
      email: str,
      endowed: bool,
      formattedMrn: str,
      gender: str,
      genderCode: int,
      genderLabelShort: str,
      householdEmail: str,
      householdPhone: str,
      htvtAssignments: NoneType,
      htvtCompanions: NoneType,
      id: int,
      mrn: str,
      name: str,
      nameOrder: int,
      nonMember: bool,
      notAccountable: bool,
      outOfUnitMember: bool,
      phone: str,
      priesthood: str,
      priesthoodCode: int,
      priesthoodType: str,
      sealedToSpouse: bool,
      setApart: bool,
      spokenName: str,
      sustainedDate: NoneType,
      unitName: str,
      unitNumber: int,
      visible: NoneType
    }
  ],
  mergeableSubOrgTypeIds: list,
  missionaries: bool,
  multipleAllowed: bool,
  name: str,
  nameEditable: bool,
  orgTypeIds: [
    int
  ],
  other: bool,
  parentName: str,
  parentSubOrgId: NoneType,
  positionTypeIdsThatCanHaveResponsibilities: list,
  priesthood: bool,
  relatedSubOrgName: NoneType,
  required: bool,
  resetable: bool,
  room: NoneType,
  size: NoneType,
  splitOrCombinedClassNotice: NoneType,
  subOrgId: int,
  supportsAttendanceRoll: bool,
  totalInstances: int,
  unitNumber: int,
  unitType: int,
  userCanEditCallings: bool,
  userCanEditClassAssignments: bool,
  userCanSeeBasicInfo: bool
}
